"""Envie cross-platform utils, serving as a fallback if a tool is not available
on a particular user's platform."""

import os.path


def readlink(path, *args):
    """Emulate GNU coretools' `readlink -m <path>`.
    Return canonical (normalized, absolute) path by following every symlinks,
    without requirements on components existence.
    """
    return os.path.realpath(os.path.expanduser(path))


def realpath(path, start=None, *args):
    """Emulate GNU coretools' `realpath --relative-to=<start> <path>`.
    Extends `readlink` to return canonical path relative to `start`.
    Without `start` (None, missing, or empty string), equivalent to `readlink`.
    """
    path = readlink(path)
    if not start:
        return path
    return os.path.relpath(path, start)



#!/usr/bin/env python
import re
from setuptools import setup

def parse_envie_version():
    for line in open('scripts/envie').readlines():
        m = re.match(r'^_ENVIE_VERSION="([^"]+)"$', line)
        if m:
            return m.group(1)

setup(
    name='envie',
    version=parse_envie_version(),
    description="Bash helpers for navigating and managing Python VirtualEnvs.",
    long_description=open('README.rst').read(),
    author='Radomir Stevanovic',
    author_email='radomir.stevanovic@gmail.com',
    url='https://github.com/randomir/envie',
    license='MIT',
    packages=['envie'],
    package_dir={'envie': 'envie'},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Unix Shell',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Topic :: Utilities',
        'Topic :: System :: Shells'
    ],
    keywords='virtualenv bash helper closest virtual environment create mkenv destroy rmenv change chenv activate discover find findenv list lsenv cdenv',
    scripts=['scripts/envie', 'scripts/envie-oneoff', 'scripts/envie-tools']
)
